///
/// \file Cursor.h
/// \author kyle 
/// \created 10/11/23
/// \brief Cursor describes a position in a Buffer.
///
/// \section COPYRIGHT
/// Copyright 2023 K. Isom <kyle@imap.cc>
///
/// Permission to use, copy, modify, and/or distribute this software for
/// any purpose with or without fee is hereby granted, provided that the
/// above copyright notice and this permission notice appear in all copies.
///
/// THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL
/// WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED
/// WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR
/// BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES
/// OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
/// WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
/// ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
/// SOFTWARE.
///

#ifndef KEPP__CURSOR_H_
#define KEPP__CURSOR_H_


#include <cstddef>
#include <ostream>


/// Cursors represent a position in a Buffer.
class Cursor {
public:
    	Cursor() : x(0), y(0) {}
	Cursor(size_t _x, size_t _y) : x(_x), y(_y) {}

	size_t	X() const { return this->x; }
	size_t	Y() const { return this->y; }
	void X(size_t nx) { this->x = nx; }
	void Y(size_t ny) { this->y = ny; }

	void Update(size_t nx, size_t ny) { this->X(nx); this->Y(ny); }
	Cursor Update(const Cursor &c);

	size_t	Distance(const Cursor &c) const;

private:
	size_t	x;
	size_t	y;
};


std::ostream &operator<<(std::ostream &os, const Cursor &cursor);


#endif // KEPP__CURSOR_H_
